================
pytorch-nn-tools
================


.. image:: https://img.shields.io/pypi/v/pytorch-nn-tools.svg
        :target: https://pypi.python.org/pypi/pytorch-nn-tools

.. image:: https://travis-ci.org/serge-m/pytorch-nn-tools.svg
        :target: https://travis-ci.org/github/serge-m/pytorch-nn-tools/

.. image:: https://readthedocs.org/projects/pytorch-nn-tools/badge/?version=latest
        :target: https://pytorch-nn-tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Tools for NN creation with Pytorch. The project is greatly inspired by fast.ai library.
The project brings the convenience functions from fast.ai to a usual pytorch user.



* Free software: MIT license
* Documentation: https://pytorch-nn-tools.readthedocs.io.

